@@ -16,13 +16,33 @@
 #include <KUserFeedback/Provider>
 #endif
 
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
+
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
+
 int main(int argc, char *argv[])
 {
+#if HAVE_KICONTHEME
+    KIconTheme::initTheme();
+#endif
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("pimdataexporter"));
 
     KCrash::initialize();
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif
+#endif
     app.setDesktopFileName(QStringLiteral("org.kde.pimdataexporter"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kontact")));
 
@@ -36,7 +56,9 @@ int main(int argc, char *argv[])
         return 0;
     }
 #endif
+#if HAVE_KDBUSADDONS
     KDBusService service(KDBusService::Unique);
+#endif
 
     auto backupMailWin = new PimDataExporterWindow();
     parser.setExportWindow(backupMailWin);
